libhomfly: Compute the homfly polynomial of knots and links
===========================================================

Description
-----------

libhomfly is a library to compute the homfly polynomial of knots and
links.

License
-------

Public domain


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)

https://github.com/miguelmarco/libhomfly
